# pyPETB

[![python](https://img.shields.io/badge/Python-3.9-3776AB.svg?style=flat&logo=python&logoColor=white)](https://www.python.org)
[![jupyter](https://img.shields.io/badge/Jupyter-Lab-F37626.svg?style=flat&logo=Jupyter)](https://jupyterlab.readthedocs.io/en/stable)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Process Engineer Tool Box is a package where a set of tools are developed to help in our daily tasks

## 1- INTRODUCTION

![Visual Studio Code](https://img.shields.io/badge/Visual%20Studio%20Code-0078d7.svg?style=for-the-badge&logo=visual-studio-code&logoColor=white)
![Poetry](https://img.shields.io/badge/Poetry-%233B82F6.svg?style=for-the-badge&logo=poetry&logoColor=0B3D8D) 

This package is based on the use of pandas. In daily chemical industry task, focused on data analysis
and improvement projects developing, no long dataset are
usually used and pandas cover all the requirements.

## 2- INSTALLATION

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install pyPETB.

```bash
pip install pyPETB
```

## 3- USAGE

Please refer to the [Documentation](https://pypetb.readthedocs.io/en/latest/)

## 4- LICENSE

Distributed under the MIT License. See LICENSE.txt for more information.

## 5- ACKNOLEDGMENTS

- Thanks to Noël Santiago for his coaching during our six sigma green belt training
- Thanks to Alexandre Baharov for sharing the statistic tables script
- Thanks to Ted Hessing for his detailed article calculating RnR:
https://sixsigmastudyguide.com/repeatability-and-reproducibility-rr/
